SCRIPT_NAME=elf
TEMPLATE_NAME=generic
EXTRA_EM_FILE=genelf
OUTPUT_FORMAT="elf32-i960"
NO_RELA_RELOCS=yes
ARCH=i960
MACHINE=
TEXT_START_ADDR=0
EMBEDDED=yes
MAXPAGESIZE="CONSTANT (MAXPAGESIZE)"
